@@ -26,9 +26,9 @@ __metaclass__ = type
 
 import os.path as osp
 import os
-import subprocess
 import sys
 import tempfile
+from logilab.common.compat import sorted, reversed, str_encode
 
 def escape(value):
     """Make <value> usable in a dot file."""
@@ -85,6 +85,7 @@ class DotBackend:
         :rtype: str
         :return: a path to the generated file
         """
+        import subprocess # introduced in py 2.4
         name = self.graphname
         if not dotfile:
             # if 'outputfile' is a dot file use it as 'dotfile'
@@ -105,11 +106,8 @@ class DotBackend:
             ppng, outputfile = tempfile.mkstemp(".png", name)
             os.close(pdot)
             os.close(ppng)
-        pdot = open(dot_sourcepath,'w')
-        if isinstance(self.source, unicode):
-            pdot.write(self.source.encode('UTF8'))
-        else:
-            pdot.write(self.source)
+        pdot = open(dot_sourcepath, 'w')
+        pdot.write(str_encode(self.source, 'utf8'))
         pdot.close()
         if target != 'dot':
             if mapfile:
@@ -183,12 +181,12 @@ def ordered_nodes(graph):
     """
     cycles = get_cycles(graph)
     if cycles:
-        cycles = '\n'.join(' -> '.join(cycle) for cycle in cycles)
+        cycles = '\n'.join([' -> '.join(cycle) for cycle in cycles])
         raise UnorderableGraph(cycles)
     ordered = []
     while graph:
         # sorted to get predictable results
-        for node, deps in sorted(graph.items()):
+        for node, deps in sorted(graph.items(), key=id):
             if not deps:
                 ordered.append(node)
                 del graph[node]
